@@ -15,6 +15,7 @@ newtonraphson_show <- function(ftn, x0, xmin = x0-1, xmax = x0+1) {
 
   # do first iteration
   xold <- x0
+  #  iter <- 1
   f.xold <- ftn(xold)
   xnew <- xold - f.xold[1]/f.xold[2]
   lines(c(xold, xold, xnew), c(0, f.xold[1], 0), col = "red")
@@ -26,7 +27,7 @@ newtonraphson_show <- function(ftn, x0, xmin = x0-1, xmax = x0+1) {
     xold <- xnew;
     f.xold <- ftn(xold)
     xnew <- xold - f.xold[1]/f.xold[2]
-    iter <-  iter + 1
+    #  iter <-  iter + 1
     lines(c(xold, xold, xnew), c(0, f.xold[1], 0), col = "red")
     cat("last x value", xnew, " ")
     continue <- readline("continue (y or n)? ") == "y"
